@@ -316,6 +316,18 @@ class Model:
         """
         return self.__variables
 
+    @property
+    def variable(self, name):
+        """
+        Documentation
+        """
+        result = None
+        for variable in self.__variables:
+            if variable.name == name:
+                result = variable
+                break
+        return result
+
     @property
     def styles(self):
         """
@@ -343,6 +355,56 @@ class Model:
             rows_height.append([row.name, row.value])
         return rows_height
 
+    def calculating_rows(self, data):
+        """
+        Documentation
+        """
+        dict = {}
+        positions = {}
+        tables = {}
+        for name in self.variablenames:
+            if 'tbl' in name:
+                positions.update({name:variable(name).row})
+
+        for name in self.variablenames:
+            if 'tbl' in name:
+                n = 0
+                for tbl in data['table']:
+                    if name == tbl:
+                        n += 1
+                dict.update({name:[positions[name],n]})
+
+        for key in dict:
+            s = str(dict[key][0])+':'+str(dict[key][1])
+            tables.update({s:key})
+        result = []
+        for key in tables:
+            p = table.split(':')[0]
+            n = table.split(':')[1]
+            result.update([p,n])
+        return result
+
+    def import_data(self, data):
+        """
+        Documentation
+        """
+
+        """
+        for variable in self.variables:
+            if variable.name in data:
+                variable.value = data[variable.name]
+            elif 'table' in data:
+
+
+                for tbl in data['table']:
+                    n = 0
+                    for variable2 in self.variables:
+                        if variable.name
+                    if variable.name in data['table']:
+
+                for variable in self.variables:
+                    if variable.row >
+    """
     def past_in_worksheet(self,worksheet):
         """
         Documentation
